@@ -111,11 +111,14 @@ class FileHandler:
     def get_srtm_dir(self):
         """ The default path to store files. """
         # Local cache path:
-        if not mod_os.environ.has_key('HOME'):
+        result = ""
+        if mod_os.environ.has_key('HOME'):
+            result = '{0}/.srtm'.format(mod_os.environ['HOME'])
+        elif mod_os.environ.has_key('HOMEPATH'):
+            result = '{0}/.srtm'.format(mod_os.environ['HOMEPATH'])
+        else:
             raise Error('No default HOME directory found, please specify a path where to store files')
 
-        result = '{0}/.srtm'.format(mod_os.environ['HOME'])
-
         if not mod_path.exists(result):
             mod_os.makedirs(result)
 
@@ -125,9 +128,9 @@ class FileHandler:
         return mod_path.exists('%s/%s' % (self.get_srtm_dir(), file_name))
 
     def write(self, file_name, contents):
-        with open('%s/%s' % (self.get_srtm_dir(), file_name), 'w') as f:
+        with open('%s/%s' % (self.get_srtm_dir(), file_name), 'wb') as f:
             f.write(contents)
 
     def read(self, file_name):
-        with open('%s/%s' % (self.get_srtm_dir(), file_name), 'r') as f:
+        with open('%s/%s' % (self.get_srtm_dir(), file_name), 'rb') as f:
             return f.read()
